summaryrefslogtreecommitdiff
path: root/addons/base_import_module/tests/test_module/static/src
diff options
context:
space:
mode:
authorDenis Ledoux <dle@odoo.com>2018-12-17 15:00:26 +0100
committerDenis Ledoux <dle@odoo.com>2018-12-17 15:00:45 +0100
commita91ffcf1a72f7d8759704405cd5026cf32c21a7f (patch)
tree9637f04fad1c86ad89f8dcc0e0c8fe01d0a74f6d /addons/base_import_module/tests/test_module/static/src
parent8373bafbc2a49bca7007ce32e96fb719fd74f1de (diff)
[IMP] product: product & template name_get performance
By prefetching only the fields required for the `name_get` `product.product` & `product.template` have a huge number of fields, and prefetching them just to compute the name is overkill. Especially, as the browse was done using sudo, the prefetch was a bit useless as it was stored in the sudo user cache, which was most-likely not used afterwards by the callee of name_get For a database with 50.000 products, this reduce the processing time by 15 (from 60 seconds to 4 seconds measured)
Diffstat (limited to 'addons/base_import_module/tests/test_module/static/src')
0 files changed, 0 insertions, 0 deletions